@@ -9,7 +9,6 @@
 
 #include "session.h"
 #include "session_p.h"
-#include "sessionuiproxy.h"
 
 #include <QTimer>
 #include <QPointer>
@@ -347,7 +346,7 @@ void SessionPrivate::socketConnected()
 
     bool willUseSsl = false;
     if (!queue.isEmpty()) {
-        KIMAP::LoginJob *login = qobject_cast<KIMAP::LoginJob *>(queue.first());
+        auto *login = qobject_cast<KIMAP::LoginJob *>(queue.first());
         if (login) {
             willUseSsl = (login->encryptionMode() == KIMAP::LoginJob::SSLorTLS);
 
